@@ -14,6 +14,7 @@
 
 from interfaces import *
 from text import *
+from gi.repository import Atspi
 
 __all__ = [
            "EditableText",
@@ -39,8 +40,7 @@ class EditableText(Text):
                 the offset of the first character past the end of the range of
                 text being copied.
                 """
-                func = self.get_dbus_method("CopyText", dbus_interface=ATSPI_EDITABLE_TEXT)
-                return func(start, end)
+                return Atspi.EditableText.copy_text(self.obj, start, end)
 
         def cutText(self, start, end):
                 """
@@ -54,8 +54,7 @@ class EditableText(Text):
                 text being cut. 
                 @return True if the text was successfully cut, False otherwise.
                 """
-                func = self.get_dbus_method("CutText", dbus_interface=ATSPI_EDITABLE_TEXT)
-                return func(start, end)
+                return Atspi.EditableText.cut_text(self.obj, start, end)
 
         def deleteText(self, start, end):
                 """
@@ -69,8 +68,7 @@ class EditableText(Text):
                 text being deleted. 
                 @return True if the text was successfully deleted, False otherwise.
                 """
-                func = self.get_dbus_method("DeleteText", dbus_interface=ATSPI_EDITABLE_TEXT)
-                return func(start, end)
+                return Atspi.EditableText.delete_text(self.obj, start, end)
 
         def insertText(self, position, text, length):
                 """
@@ -89,8 +87,7 @@ class EditableText(Text):
                 @return True if the text content was successfully inserted, False
                 otherwise.
                 """
-                func = self.get_dbus_method("InsertText", dbus_interface=ATSPI_EDITABLE_TEXT)
-                return func(position, text, length)
+                return Atspi.EditableText.insert_text(self.obj, position, text, length)
 
         def pasteText(self, position):
                 """
@@ -101,8 +98,7 @@ class EditableText(Text):
                 @return True if the text was successfully pasted into the Text
                 object, False otherwise.
                 """
-                func = self.get_dbus_method("PasteText", dbus_interface=ATSPI_EDITABLE_TEXT)
-                return func(position)
+                return Atspi.EditableText.paste_text(self.obj, position)
 
         def setTextContents(self, contents):
                 """
@@ -114,7 +110,6 @@ class EditableText(Text):
                 @return True if the text content was successfully changed, False
                 otherwise.
                 """
-                func = self.get_dbus_method("SetTextContents", dbus_interface=ATSPI_EDITABLE_TEXT)
-                return func(contents)
+                return Atspi.EditableText.set_text_contents(self.obj, contents)
 
 #END----------------------------------------------------------------------------
